{% extends "partials/forms/form_base.html" %}
{% load i18n %}

{% block form_submit_btn_variation %}default{% endblock form_submit_btn_variation %}
{% block form_close_btn_variation %}default{% endblock form_close_btn_variation %}
