{% load i18n %}

{% if form.non_field_errors %}
    {% for error in form.non_field_errors %}
        <div class="alert alert-danger">
            <i class="icon-exclamation-sign"></i> {{ error }}
        </div>
    {% endfor %}
{% endif %}
