{% load i18n %}

{% for file in folder_files %}
    <a href="{{ file.url }}"
        {% if instance.link_target %} target="{{ instance.link_target }}"{% endif %}
        {{ instance.attributes_str }}>
        {{ file }}
        {% if instance.show_file_size %}
            <span>{{ file.size|filesizeformat }}</span>
        {% endif %}
    </a>
    {% if not forloop.last %}<br>{% endif %}
{% empty %}
    <p>{% trans "No files were found in the specified folder." %}</p>
{% endfor %}

{% comment %}
    # https://github.com/divio/django-filer/blob/master/filer/models/filemodels.py
    {{ instance.folder_src }}
    {{ instance.get_files }} or {{ folder_files }}
    # Available variables:
    {{ instance.template }}
    {{ instance.link_target }}
    {{ instance.show_file_size }}
    {{ instance.attributes_str }}
{% endcomment %}
