{% if messages %}
    {% for message in messages %}
        <div class="alert alert-message{% if message.tags %} alert-{{ message.tags }}{% endif %}">
            <p>{{ message }}</p>
        </div>
    {% endfor %}
{% endif %}
