<span class="link-text">{% if icon %} {% include "partials/buttons/link_icon_left.html" %} {% endif %} <span>{{ link_label }}</span> {% if icon %} {% include "partials/buttons/link_icon_right.html" %} {% endif %} </span>{# container for css masking effect #} {% block link_mask %} <span class="link-text-mask"><span class="link-text-mask__inner">{% if icon %} {% include "partials/buttons/link_icon_left.html" %} {% endif %} <span>{{ link_label }}</span> {% if icon %} {% include "partials/buttons/link_icon_right.html" %} {% endif %} </span></span>{% endblock link_mask %}
