<blockquote class="quote-plugin">
    <h2 class="quote__text"><span class="quote__quotation-mark">«</span>{{ instance.text }}<span class="quote__quotation-mark">»</span></h2>
    <div class="quote__author">{{ instance.author }}</div>
    <div class="quote__author-description">{{ instance.author_description }}</div>
</blockquote>
