# -*- coding: utf-8 -*-
"""
use core:
no 'sitemaps.py' file needed
"""
from allink_core.apps.dummy_app.sitemaps import DummyAppSitemap as CoreDummyAppSitemap


class DummyAppSitemap(CoreDummyAppSitemap):
    pass
