{% load i18n staticfiles cms_tags inline_static_tags %}

<header class="site-header compact-mode-enabled {% block header_class %}{% endblock header_class %}">
    <div class="site-header__animated">
        <div class="site-header__container">
            <div class="brand-logo">
                <a class="brand-logo__link" href="{% url 'pages-root' %}" aria-label="Brand Logo">
                    {% comment %} IMPORTANT: You must use class '.brand-logo__image' to change fill color from scss {% endcomment %}
                    {% inline_style 'images/branding/brand-logo-compact.svg' %}
                </a>
            </div>

            <div class="site-header__border"></div>
        </div>
    </div>

    <div class="nav-toggle__container">
        <a
            href="#"
            class="nav-toggle"
        >
            <span class="sr-only">{% trans "Toggle navigation" %}</span>
            <div class="nav-toggle__box">
                <div class="nav-toggle__line"></div>
                <div class="nav-toggle__line"></div>
            </div>
        </a>
    </div>

</header>
