{% load i18n menu_tags %}
{% get_language_info for request.LANGUAGE_CODE as lang %}

{% if languages|length > 1 %}
    {% for language in languages %}
        <li class="language-list__item {% if language.0 == current_language %}language-list__item--active{% endif %}">
            <a class="language-list__link" href="{% page_language_url language.0 %}">
                <span class="language-list__text">{{ language.0 }}</span>
            </a>
        </li>
    {% endfor %}
{% endif %}
