{# Page Title #}
{% if meta_page_title %}<title>{{ meta_page_title }}</title>{% endif %}
{# META Block#}
<link rel="canonical" href="{{ request.build_absolute_uri }}"/>
{% if meta_description %}
<meta name="description" content="{{ meta_description }}"/>
{% endif %}
{% if google_site_verification %}
<meta name="google-site-verification" content="{{ google_site_verification }}"/>
{% endif %}
{# OpenGraph Block#}
<meta property="og:type" content="website"/>
<meta property="og:url" content="{{ request.build_absolute_uri }}"/>
{% if meta_title %}
<meta property="og:title" content="{{ meta_title }}"/>
{% endif %}
{% if meta_description %}
<meta property="og:description" content="{{ meta_description }}"/>{% endif %}
{% if meta_image_url %}
<meta property="og:image" content="{{ meta_image_url }}"/>
<meta property="og:image:width" content="1200"/>
<meta property="og:image:height" content="630"/>
{% endif %}




