# Generated by Django 2.1.10 on 2019-07-23 11:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allink_legacy_redirect', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='allinklegacylink',
            name='language',
            field=models.CharField(choices=[('en', 'English'), ('de', 'German')], default=('en', 'English'), max_length=200, null=True, verbose_name='Language'),
        ),
    ]
