{% load i18n %}

{% if teaser_link %}
    <div class="teaser__link">
        <button class="{% if teaser_link_classes %} {{ teaser_link_classes }} {% else %} btn {% endif %}" {% if icon %}data-icon-{{ icon }}{% endif %}>
            {% include "partials/buttons/link_text.html" with link_label=teaser_link_text icon=icon %}
        </button>
    </div>
{% endif %}
