# Generated by Django 2.1.9 on 2019-07-03 15:28

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
        ('allink_teaser', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='allinkteaserplugin',
            name='teaser_description',
            field=models.TextField(blank=True, default='', help_text='Page: no fallback.<br>App: fallback is field "lead".', verbose_name='Teaser description'),
        ),
        migrations.AddField(
            model_name='allinkteaserplugin',
            name='teaser_image',
            field=filer.fields.image.FilerImageField(blank=True, help_text='Optional field for teaser image. og: properties are used when shared on Facebook/ Twitter etc. (Min. 1200 x 630 px)<br>Also used as "meta" property="og:image"<br>Page: 1. fallback is allink_config.default_og_image.<br>App: 1. fallback = preview_image 2. fallback is defined in allink_config.default_og_image.<br>', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='allink_teaser_allinkteaserplugin_teaser_image', to=settings.FILER_IMAGE_MODEL, verbose_name='Teaser image'),
        ),
        migrations.AddField(
            model_name='allinkteaserplugin',
            name='teaser_link_text',
            field=models.CharField(blank=True, default='', help_text='Page: no fallback.<br>App: fallback is hardcoded per app in the teaser_dict.', max_length=255, verbose_name='Teaser link text'),
        ),
        migrations.AddField(
            model_name='allinkteaserplugin',
            name='teaser_technical_title',
            field=models.CharField(blank=True, default='', help_text='Page: no fallback.<br>App: fallback is hardcoded per app in the teaser_dict.', max_length=255, verbose_name='Teaser technical title'),
        ),
        migrations.AddField(
            model_name='allinkteaserplugin',
            name='teaser_title',
            field=models.CharField(blank=True, default='', help_text='Page: fallback is field "title" of the page.<br>App: fallback is field "title".', max_length=255, verbose_name='Teaser title'),
        ),
    ]
