# Generated by Django 2.2.9 on 2020-03-23 19:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allink_image', '0002_auto_20191002_1951'),
    ]

    operations = [
        migrations.AlterField(
            model_name='allinkimageplugin',
            name='icon_enabled',
            field=models.BooleanField(blank=True, default=False, help_text='Show the icon that is used as long as the image is loading.<br><strong>Important:</strong> Disable this option if a transparent PNG image is used.', verbose_name='Loader Icon'),
        ),
    ]
