# Generated by Django 2.1.8 on 2019-07-02 17:18

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='AllinkInfoBoxPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_info_box_allinkinfoboxplugin', serialize=False, to='cms.CMSPlugin')),
                ('counter', models.IntegerField(choices=[(0, 'Always visible'), (1, '1x'), (2, '2x'), (3, '3x'), (4, '4x'), (5, '5x')], default=0, help_text='After how many times/clicks should the box not be visible anymore', verbose_name='Display duration')),
                ('transparent_background', models.BooleanField(default=False, verbose_name='Transparent background')),
                ('template', models.CharField(help_text='Choose a template.', max_length=50, verbose_name='Template')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
