{% extends "admin/parler/change_form.html" %}
{% load i18n %}
{% load admin_urls %}

{% block object-tools-items %}
    <li><a href="{% url opts|admin_urlname:'clearcache' original.pk %}">{% trans "clear cache" %}</a></li>
    {{ block.super }}
{% endblock %}
