{% load cms_tags %}

{% with instance.parent.allink_seo_accordion_allinkseoaccordioncontainerplugin.is_seo_faq as is_seo_faq %}
    <div class="seo-accordion__item"
            {% if is_seo_faq %}
                itemscope itemprop="mainEntity" itemtype="https://schema.org/Question"
            {% endif %}
        >
        <a href="#" class="seo-accordion__title" role="presentation">
            <h3
                {% if is_seo_faq %}
                    itemprop="name"
                {% endif %}
            >{{ instance.title }}</h3>
        </a>

        <div class="seo-accordion__content"
            {% if is_seo_faq %}
                 itemscope itemprop="acceptedAnswer" itemtype="https://schema.org/Answer"
            {% endif %}
        >
            {% for plugin in instance.child_plugin_instances %}
                <div
                    {% if is_seo_faq %}
                        itemprop="text"
                    {% endif %}
                >
                {% render_plugin plugin %}
                </div>
            {% endfor %}
        </div>
    </div>
{% endwith %}