# Generated by Django 2.1.8 on 2019-07-02 17:18

import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='AllinkSocialIconContainerPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_social_icon_allinksocialiconcontainerplugin', serialize=False, to='cms.CMSPlugin')),
                ('project_css_classes', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=50, null=True), blank=True, null=True, size=None)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='AllinkSocialIconPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_social_icon_allinksocialiconplugin', serialize=False, to='cms.CMSPlugin')),
                ('title', models.CharField(blank=True, help_text='SEO text (not visible) e.g. Follow allink on Instagram', max_length=255, null=True, verbose_name='Title')),
                ('icon', models.CharField(max_length=50, verbose_name='Icon')),
                ('link', models.URLField(verbose_name='Link')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
