{% load staticfiles %}
<link rel="icon" type="image/png" href="{% static 'images/favicons/android-chrome-192x192.png' %}">
<link rel="icon" type="image/png" href="{% static 'images/favicons/android-chrome-384x384.png' %}">
<link rel="apple-touch-icon" sizes="114x114"
      href="{% static 'images/favicons/apple-touch-icon-114x114-precomposed.png' %}">
<link rel="apple-touch-icon" sizes="114x114" href="{% static 'images/favicons/apple-touch-icon-114x114.png' %}">
<link rel="apple-touch-icon" sizes="120x120"
      href="{% static 'images/favicons/apple-touch-icon-120x120-precomposed.png' %}">
<link rel="apple-touch-icon" sizes="120x120" href="{% static 'images/favicons/apple-touch-icon-120x120.png' %}">
<link rel="apple-touch-icon" sizes="144x144"
      href="{% static 'images/favicons/apple-touch-icon-144x144-precomposed.png' %}">
<link rel="apple-touch-icon" sizes="144x144" href="{% static 'images/favicons/apple-touch-icon-144x144.png' %}">
<link rel="apple-touch-icon" sizes="152x152"
      href="{% static 'images/favicons/apple-touch-icon-152x152-precomposed.png' %}">
<link rel="apple-touch-icon" sizes="152x152" href="{% static 'images/favicons/apple-touch-icon-152x152.png' %}">
<link rel="apple-touch-icon" sizes="180x180"
      href="{% static 'images/favicons/apple-touch-icon-180x180-precomposed.png' %}">
<link rel="apple-touch-icon" sizes="180x180" href="{% static 'images/favicons/apple-touch-icon-180x180.png' %}">
<link rel="apple-touch-icon" sizes="57x57"
      href="{% static 'images/favicons/apple-touch-icon-57x57-precomposed.png' %}">
<link rel="apple-touch-icon" sizes="57x57" href="{% static 'images/favicons/apple-touch-icon-57x57.png' %}">
<link rel="apple-touch-icon" sizes="60x60"
      href="{% static 'images/favicons/apple-touch-icon-60x60-precomposed.png' %}">
<link rel="apple-touch-icon" sizes="60x60" href="{% static 'images/favicons/apple-touch-icon-60x60.png' %}">
<link rel="apple-touch-icon" sizes="72x72"
      href="{% static 'images/favicons/apple-touch-icon-72x72-precomposed.png' %}">
<link rel="apple-touch-icon" sizes="72x72" href="{% static 'images/favicons/apple-touch-icon-72x72.png' %}">
<link rel="apple-touch-icon" sizes="76x76"
      href="{% static 'images/favicons/apple-touch-icon-76x76-precomposed.png' %}">
<link rel="apple-touch-icon" sizes="76x76" href="{% static 'images/favicons/apple-touch-icon-76x76.png' %}">
<link rel="apple-touch-icon" href="{% static 'images/favicons/apple-touch-icon-precomposed.png' %}">
<link rel="apple-touch-icon" href="{% static 'images/favicons/apple-touch-icon.png' %}">
<meta name="msapplication-config" content="{% static 'images/favicons/browserconfig.xml' %}"/>
<link rel="icon" sizes="16x16" type="image/png" href="{% static 'images/favicons/favicon-16x16.png' %}">
<link rel="icon" sizes="194x194" type="image/png" href="{% static 'images/favicons/favicon-194x194.png' %}">
<link rel="icon" sizes="32x32" type="image/png" href="{% static 'images/favicons/favicon-32x32.png' %}">
<link rel="icon" href="{% static 'images/favicons/favicon.ico' %}">
<meta name="msapplication-TileImage" content="{% static 'images/favicons/mstile-144x144.png' %}">
<meta name="msapplication-TileImage" content="{% static 'images/favicons/mstile-150x150.png' %}">
<meta name="msapplication-TileImage" content="{% static 'images/favicons/mstile-310x150.png' %}">
<meta name="msapplication-TileImage" content="{% static 'images/favicons/mstile-310x310.png' %}">
<meta name="msapplication-TileImage" content="{% static 'images/favicons/mstile-70x70.png' %}">
<link rel="mask-icon" href="{% static 'images/favicons/safari-pinned-tab.svg' %}" color=" #3e3e3d">
<link rel="manifest" href="{% static 'images/favicons/site.webmanifest' %}">
<meta name="msapplication-TileColor" content=" #3e3e3d">
<meta name="theme-color" content=" #3e3e3d">
