{% load i18n staticfiles cms_tags menu_tags %}

<div class="content-plugin languagechooser-plugin">
    <div class="languagechooser-plugin__container">
        <ul class="language-list">
            {% language_chooser "includes/menu/langnav.html" "native" %}
        </ul>
    </div>
</div>
