# Generated by Django 2.2.7 on 2020-02-05 14:36

from django.db import migrations

def set_new_default_value(apps, schema_editor):
    AllinkTeaserPlugin = apps.get_model('allink_teaser', 'AllinkTeaserPlugin')
    for teaser in AllinkTeaserPlugin.objects.all():
        teaser.softpage_enabled = False
        teaser.save()


class Migration(migrations.Migration):

    dependencies = [
        ('allink_teaser', '0005_auto_20200205_1427'),
    ]

    operations = [
        migrations.RunPython(set_new_default_value),
    ]
