# Generated by Django 2.2.7 on 2020-01-24 10:10

from django.db import migrations, models
import djangocms_text_ckeditor.fields


class Migration(migrations.Migration):

    dependencies = [
        ('config', '0002_auto_20190716_0951'),
    ]

    operations = [
        migrations.AddField(
            model_name='config',
            name='newsletter_teaser_counter',
            field=models.IntegerField(default=4, help_text='Number which defines after how many newsentries the newsletter teaser should appear (on grid with newsletterteaser). Default is 4', verbose_name='Newsletter Teaser Counter'),
        ),
        migrations.AddField(
            model_name='configtranslation',
            name='newsletter_signup_link',
            field=models.URLField(blank=True, help_text='Link for Button on Newsletter Teaser', null=True, verbose_name='Newsletter Signup Link'),
        ),
        migrations.AlterField(
            model_name='configtranslation',
            name='newsletter_lead',
            field=djangocms_text_ckeditor.fields.HTMLField(blank=True, help_text='Teaser text in the Newsletter Teaser', null=True, verbose_name='Newsletter Signup Text'),
        ),
    ]
