# Generated by Django 2.2.5 on 2019-10-16 08:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allink_legacy_redirect', '0002_auto_20190723_1107'),
    ]

    operations = [
        migrations.AlterField(
            model_name='allinklegacylink',
            name='language',
            field=models.CharField(max_length=200, null=True, verbose_name='Language'),
        ),
    ]
